==> create-fly-1.21.10-6.0.8-5-sources.jar: com/zurrtum/create/client/foundation/render/AllRenderPipelines.java <==
package com.zurrtum.create.client.foundation.render;

import com.mojang.blaze3d.pipeline.BlendFunction;
import com.mojang.blaze3d.pipeline.RenderPipeline;
import com.mojang.blaze3d.platform.DestFactor;
import com.mojang.blaze3d.platform.SourceFactor;
import com.mojang.blaze3d.vertex.VertexFormat;
import net.minecraft.class_10799;
import net.minecraft.class_290;
import net.minecraft.class_2960;

import static com.zurrtum.create.Create.MOD_ID;

public class AllRenderPipelines {
    public static final class_2960 GLOWING_ID = class_2960.method_60655(MOD_ID, "core/glowing_shader");
    public static final RenderPipeline.Snippet GLOWING_SNIPPET = RenderPipeline.builder(class_10799.field_60127)
        .withVertexShader(GLOWING_ID).withFragmentShader(GLOWING_ID).withSampler("Sampler0").withSampler("Sampler2")
        .withVertexFormat(class_290.field_1580, VertexFormat.class_5596.field_27382).buildSnippet();
    public static final RenderPipeline ADDITIVE = RenderPipeline.builder(class_10799.field_56853)
        .withLocation(class_2960.method_60655(MOD_ID, "pipeline/additive")).withBlend(BlendFunction.ADDITIVE).withCull(false).build();
    public static final RenderPipeline ADDITIVE2 = RenderPipeline.builder(class_10799.field_56853)
        .withLocation(class_2960.method_60655(MOD_ID, "pipeline/additive2")).withBlend(BlendFunction.ADDITIVE).withCull(false).withDepthWrite(false).build();
    public static final RenderPipeline GLOWING = RenderPipeline.builder(GLOWING_SNIPPET).withLocation(class_2960.method_60655(MOD_ID, "pipeline/glowing"))
        .withBlend(new BlendFunction(SourceFactor.SRC_ALPHA, DestFactor.ONE_MINUS_SRC_ALPHA, SourceFactor.SRC_ALPHA, DestFactor.ONE_MINUS_SRC_ALPHA))
        .build();
    public static final RenderPipeline GLOWING_TRANSLUCENT = RenderPipeline.builder(GLOWING_SNIPPET)
        .withLocation(class_2960.method_60655(MOD_ID, "pipeline/glowing_translucent")).withBlend(BlendFunction.TRANSLUCENT).build();
    public static final RenderPipeline CUBE = RenderPipeline.builder(class_10799.field_56861)
        .withLocation(class_2960.method_60655(MOD_ID, "pipeline/cube"))
        .withBlend(new BlendFunction(SourceFactor.SRC_ALPHA, DestFactor.ONE_MINUS_SRC_ALPHA, SourceFactor.SRC_ALPHA, DestFactor.ONE_MINUS_SRC_ALPHA))
        .withDepthWrite(false).build();
}

==> create-fly-1.21.11-pre1-6.0.8-1-sources.jar: com/zurrtum/create/client/foundation/render/AllRenderPipelines.java <==
package com.zurrtum.create.client.foundation.render;

import com.mojang.blaze3d.pipeline.BlendFunction;
import com.mojang.blaze3d.pipeline.RenderPipeline;
import com.mojang.blaze3d.platform.DestFactor;
import com.mojang.blaze3d.platform.SourceFactor;
import com.mojang.blaze3d.vertex.VertexFormat;
import net.minecraft.class_10799;
import net.minecraft.class_290;
import net.minecraft.class_2960;

import static com.zurrtum.create.Create.MOD_ID;

public class AllRenderPipelines {
    public static final class_2960 GLOWING_ID = class_2960.method_60655(MOD_ID, "core/glowing_shader");
    public static final RenderPipeline.Snippet GLOWING_SNIPPET = RenderPipeline.builder(class_10799.field_60127)
        .withVertexShader(GLOWING_ID).withFragmentShader(GLOWING_ID).withSampler("Sampler0").withSampler("Sampler2")
        .withVertexFormat(class_290.field_1580, VertexFormat.class_5596.field_27382).buildSnippet();
    public static final RenderPipeline ADDITIVE = RenderPipeline.builder(class_10799.field_64223)
        .withLocation(class_2960.method_60655(MOD_ID, "pipeline/additive")).withBlend(BlendFunction.ADDITIVE).withCull(false).build();
    public static final RenderPipeline ADDITIVE2 = RenderPipeline.builder(class_10799.field_64223)
        .withLocation(class_2960.method_60655(MOD_ID, "pipeline/additive2")).withBlend(BlendFunction.ADDITIVE).withCull(false)
        .withDepthWrite(false).build();
    public static final RenderPipeline GLOWING = RenderPipeline.builder(GLOWING_SNIPPET)
        .withLocation(class_2960.method_60655(MOD_ID, "pipeline/glowing"))
        .withBlend(new BlendFunction(SourceFactor.SRC_ALPHA, DestFactor.ONE_MINUS_SRC_ALPHA, SourceFactor.SRC_ALPHA, DestFactor.ONE_MINUS_SRC_ALPHA))
        .build();
    public static final RenderPipeline GLOWING_TRANSLUCENT = RenderPipeline.builder(GLOWING_SNIPPET)
        .withLocation(class_2960.method_60655(MOD_ID, "pipeline/glowing_translucent")).withBlend(BlendFunction.TRANSLUCENT).build();
    public static final RenderPipeline CUBE = RenderPipeline.builder(class_10799.field_56861)
        .withLocation(class_2960.method_60655(MOD_ID, "pipeline/cube"))
        .withBlend(new BlendFunction(SourceFactor.SRC_ALPHA, DestFactor.ONE_MINUS_SRC_ALPHA, SourceFactor.SRC_ALPHA, DestFactor.ONE_MINUS_SRC_ALPHA))
        .withDepthWrite(false).build();
}
